# monogusa (= lazy in Japanese)
mngs is Python utilities for ML and DSP projects

![CI](https://github.com/ywatanabe1989/mngs/actions/workflows/pip_install.yml/badge.svg)

![Hard Working Sloth](./docs/hard_working_sloth.jpg)

## Installation
Due to frequent updates and occasional issues with backward compatibility, please specify the version of mngs when installing.
``` bash
$ pip install 'mngs==1.5.0'
```

## Galleries
- [`mngs.io`](https://github.com/ywatanabe1989/mngs/tree/main/src/mngs/io#readme) Input / Output
- [`mngs.path`](https://github.com/ywatanabe1989/mngs/tree/main/src/mngs/path#readme) Path
- [`mngs.dsp`](https://github.com/ywatanabe1989/mngs/tree/main/src/mngs/dsp#readme) Digital Signal Processing
- [`mngs.res`](https://github.com/ywatanabe1989/mngs/tree/main/src/mngs/res#readme) Resource
- mngs.general
- mngs.plt
- mngs.ml
- mngs.stats

## Contact
Yusuke Watanabe (ywata1989@gmail.com).


